import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faChevronUp, faChevronDown, faClose } from "@fortawesome/free-solid-svg-icons";
import React, { Component } from "react";

export default class FuelPurchases extends Component {

    constructor(props) {
        super(props)

        this.state = {
            expanded: false,
            showModal: true,
        }
    }

    toggleExpanded = () => {
        this.setState({
            expanded: !this.state.expanded
        })
    }

    setShowModal = (value) => {
        this.setState({
            showModal: value
        })
    }
    render() {
        return (
            <>
                <div className="bg-gray-400 flex flex-row mt-4 px-3 py-1 justify-between border">
                    <div className="text-xl">Fuel Purchases</div>
                    <div className="flex flex-row items-center">
                        <div onClick={() => this.setShowModal(true)} className="mr-2 px-2 py-1 rounded bg-green-400 hover:cursor-pointer">Add</div>
                        <div className="hover:cursor-pointer" onClick={this.toggleExpanded}>
                            {
                                (this.state.expanded)
                                ? <FontAwesomeIcon icon={faChevronUp} />
                                : <FontAwesomeIcon icon={faChevronDown} />
                            }
                        </div>
                    </div>
                </div>

                {
                    (this.state.showModal)
                    ? <FuelPurchaseModal setShowModal={this.setShowModal} /> : null
                }
            </>
        )
    }
}

class FuelPurchaseModal extends Component {

  constructor(props) {
    super(props)

    this.state = {
      date: '',
      amount: 0.000,
      cost: 0.00
    }
  }

  handleChange = (event) => {
    this.setState({
      [event.target.id]: event.target.value
    })
  }

  render() {

    return (
      <>
        <div
          className="justify-center items-center flex overflow-x-hidden overflow-y-auto fixed inset-0 z-50 outline-none focus:outline-none"
        >
          <div className="relative w-auto my-6 mx-auto min-w-1/2 max-w-3xl">
            {/*content*/}
            <div className="border-0 rounded-lg shadow-lg relative flex flex-col w-full bg-white outline-none focus:outline-none">
              {/*header*/}
              <div className="flex items-start justify-between p-5 border-b border-solid border-blueGray-200 rounded-t">
                <h3 className="text-3xl font-semibold">
                  Add Fuel Purchase
                </h3>
                <button
                  className="p-1 ml-auto bg-transparent border-0 text-black opacity-5 float-right text-3xl leading-none font-semibold outline-none focus:outline-none"
                  onClick={() => this.setShowModal(false)}
                >
                  <span className="bg-transparent text-black opacity-5 h-6 w-6 text-2xl block outline-none focus:outline-none">
                    <FontAwesomeIcon icon={faClose} />
                  </span>
                </button>
              </div>
              {/*body*/}
              <div className="relative p-6 flex-auto">
                <div className="flex flex-col">
                  <input className="border" id="date" type="date" value={this.state.date} onChange={this.handleChange}/>
                  <div>Date</div>
                </div>
                <div className="flex flex-col">
                  <input id="amount" type="number" step="0.001" className="border" value={this.state.amount} onChange={this.handleChange}/>
                  Fuel Purchased
                </div>
                <div className="flex flex-col">
                  <input id="cost" type="number" step="0.01" className="border" value={this.state.cost} onChange={this.handleChange}/>
                  Total Cost
                </div>
              </div>
              {/*footer*/}
              <div className="flex items-center justify-end p-6 border-t border-solid border-blueGray-200 rounded-b">
                <button
                  className="text-red-500 background-transparent font-bold uppercase px-6 py-2 text-sm outline-none focus:outline-none mr-1 mb-1 ease-linear transition-all duration-150"
                  type="button"
                  onClick={() => this.props.setShowModal(false)}
                >
                  Close
                </button>
                <button
                  className="bg-emerald-500 text-white active:bg-emerald-600 font-bold uppercase text-sm px-6 py-3 rounded shadow hover:shadow-lg outline-none focus:outline-none mr-1 mb-1 ease-linear transition-all duration-150"
                  type="button"
                  onClick={() => this.props.setShowModal(false)}
                >
                  Add
                </button>
              </div>
            </div>
          </div>
        </div>
        <div className="opacity-25 fixed inset-0 z-40 bg-black"></div>
      </>
    )
  }
} 